Axis

Struct Axis 

pub struct Axis {
    pub user_data: AxisUserData,
    pub detents: Vec<(f32, String)>,
    pub zoomed_range: Option<(f64, f64)>,
    pub force_render: bool,
    /* private fields */
}

Fields

user_data: AxisUserDatadetents: Vec<(f32, String)>

The list of detents to draw on this axis, position and label

zoomed_range: Option<(f64, f64)>

If the plot has been zoomed in, this is the (min,max) values in data coordinates of the changed range.

force_render: bool

Force a rerendering on the next frame

Implementations

Source

impl Axis

pub fn with_configuration(user_data: AxisUserData) -> Self

pub fn update_range<F: Fn(&PlotPoint) -> f64>( &mut self, vals: &[PlotPoint], accessor: F, opposite_axis: Option<&Axis>, )

pub fn linear_scale(&self, val: f64) -> f32

pub fn linear_unscale(&self, val: f32) -> f64

pub fn log_scale(&self, val: f64) -> f64

pub fn log_unscale(&self, val: f64) -> f64

pub fn db_scale(&self, val: f64) -> f64

pub fn db_unscale(&self, val: f64) -> f64

pub fn scale_value(&self, val: f64) -> Option<f32>

pub fn unscale_value(&self, val: f32) -> f64

pub fn model_to_screen(&self, val: f64) -> f32

pub fn screen_to_model(&self, val: f32) -> f64

pub fn describe_screen_pos(&self, val: f32) -> String

pub fn needs_rerendering(&self) -> bool

pub fn get_screen_range(&self) -> f32

pub fn get_model_range(&self) -> f64