pub struct AxisUserData {
pub name: Arc<String>,
pub axis_label: Option<String>,
pub axis_formatter: Option<Box<FormatterFn>>,
pub alignment_mode: AxisAlignmentMode,
pub scale_mode: ScaleMode,
}Fields
name: Arc<String>axis_label: Option<String>Optional label to paint on this axis
axis_formatter: Option<Box<FormatterFn>>Optional formatter for the detents on this axis, accepts the data value and returns a string as the detent.
alignment_mode: AxisAlignmentModeAxis alignment mode, for centering and the like
scale_mode: ScaleModeScaling mode for this axis